import { select, arc, line } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const g = svg.append('g')
  .attr('transform', `translate(${width / 2}, ${height / 2})`);

const circle = g.append('circle');

circle.attr('r', height / 2);
circle.attr('fill', 'tan');
circle.attr('stroke', 'black');

const eyeSpacing = 101;
const eyeYOffset = -89;
const eyeRadius = 40;
const eyebrowWidth = 70;
const eyebrowHeight = 20;
const eyebrowYOffset = -70;

//add ears
const earsG = g.append('g')
    .attr('transform', `translate(0, ${eyebrowYOffset + 20})`);

const leftEar = earsG
  .append('ellipse')
    .attr('cx', -eyeSpacing * 2.6)
    .attr('cy', 30)
    .attr('rx', 20)
    .attr('ry', 70)
    .attr('fill', 'tan');

const rightEar = earsG
  .append('ellipse')
    .attr('cx', eyeSpacing * 2.6)
    .attr('cy', 30)
    .attr('rx', 20)
    .attr('ry', 70)
    .attr('fill', 'tan');

//create a ornamental mark
svg.append("circle")
   .attr("cx", 480)
   .attr("cy", 100)
   .attr("r", 20)
   .attr("fill", "red");

//create mustache and teeth
var leftmustachePoints = [
  {xValue: 472, yValue: 235},
  {xValue: 399, yValue: 285},
  {xValue: 336, yValue: 255},
  {xValue: 382, yValue: 325},
  {xValue: 489, yValue: 285}];

var rightmustachePoints = [
  {xValue: 474, yValue: 235},
  {xValue: 547, yValue: 285},
  {xValue: 610, yValue: 255},
  {xValue: 564, yValue: 325},
  {xValue: 457, yValue: 285}];

var curveGenerator = line()
  	.x((d) => d.xValue)
  	.y((d) => d.yValue)
  	.curve(d3.curveBasisClosed);

const mustache = svg.append('g')
	.attr('fill', 'black')
	.attr('stroke', 'black')
	.attr('stroke-width', 5);

const leftmustache = mustache.append('path')
  	.attr('d', curveGenerator(leftmustachePoints));

const rightmustache = mustache.append('path')
  	.attr('d', curveGenerator(rightmustachePoints));

const leftTooth = g.append('rect')
  .attr('x', -33)
	.attr('y', 36)
  .attr('width', 25)
  .attr('height', 30)
	.attr('fill', 'white')
	.attr('stroke', 'black');
	
const rightTooth = g.append('rect')
  .attr('x', -5)
	.attr('y', 36)
  .attr('width', 25)
  .attr('height', 30)
	.attr('fill', 'white')
	.attr('stroke', 'black');

const mouth = g.append('path').attr(
  'd',
  arc()({
    innerRadius: 73,
    outerRadius: 98,
    startAngle: Math.PI / 1.7,
    endAngle: (Math.PI * 3) / 2.2,
  })
);

//create a beard
var beardPoints = [
  {xValue: 550, yValue: 450},
  {xValue: 300, yValue: 309},
  {xValue: 470, yValue: 550},
  {xValue: 620, yValue: 392},
  {xValue: 600, yValue: 340},
  {xValue: 547, yValue: 405},
  {xValue: 550, yValue: 370},
  {xValue: 299, yValue: 405}];

const beard = svg.append('path')
  	.attr('d', curveGenerator(beardPoints))
		.attr('fill', 'black')
		.attr('stroke', 'black')
		.attr('stroke-width', 5);


const eyesG = g
  .append('g')
    .attr('transform', `translate(0, ${eyeYOffset})`);

const leftEye = eyesG
  .append('circle')
    .attr('r', eyeRadius)
    .attr('cx', -eyeSpacing);

const rightEye = eyesG
  .append('circle')
    .attr('r', eyeRadius)
    .attr('cx', eyeSpacing);

const eyebrowsG = eyesG
  .append('g')
    .attr('transform', `translate(0, ${eyebrowYOffset})`);

eyebrowsG
  .transition().duration(2000)
    .attr('transform', `translate(0, ${eyebrowYOffset - 50})`)
  .transition().duration(2000)
    .attr('transform', `translate(0, ${eyebrowYOffset})`);

const leftEyebrow = eyebrowsG
  .append('rect')
    .attr('x', -eyeSpacing - eyebrowWidth / 2)
    .attr('width', eyebrowWidth)
    .attr('height', eyebrowHeight);

const rightEyebrow = eyebrowsG
  .append('rect')
    .attr('x', eyeSpacing - eyebrowWidth / 2)
    .attr('width', eyebrowWidth)
    .attr('height', eyebrowHeight); 

//nose
const noseBridge = g
  .append('rect')
    .attr('x', -10)
    .attr('y', -75)
    .attr('width', 20)
    .attr('height', 50)
    .attr('fill', 'beige');

const nose2 = g
  .append('circle')
    .attr('cx', 10)
  	.attr('cy', -35)
  	.attr('r', 10)
  	.attr('fill', 'beige')

const nose = g
  .append('circle')
    .attr('cx', -10)
  	.attr('cy', -35)
  	.attr('r', 10)
  	.attr('fill', 'beige');

//hair


const hair17 = g
  .append('circle')
    .attr('cx', 100)
  	.attr('cy', -90)
  	.attr('r', 15)
  	.attr('fill', 'white')

const hair16 = g
  .append('circle')
    .attr('cx', -100)
  	.attr('cy', -90)
  	.attr('r', 15)
  	.attr('fill', 'white')

const hair15 = g
  .append('circle')
    .attr('cx', 230)
  	.attr('cy', -90)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair14 = g
  .append('circle')
    .attr('cx', -230)
  	.attr('cy', -100)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair13 = g
  .append('circle')
    .attr('cx', 210)
  	.attr('cy', -124)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair12 = g
  .append('circle')
    .attr('cx', -210)
  	.attr('cy', -130)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair11 = g
  .append('circle')
    .attr('cx', 185)
  	.attr('cy', -152)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair10 = g
  .append('circle')
    .attr('cx', -180)
  	.attr('cy', -155)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair9 = g
  .append('circle')
    .attr('cx', 155)
  	.attr('cy', -175)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair8 = g
  .append('circle')
    .attr('cx', -150)
  	.attr('cy', -178)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair7 = g
  .append('circle')
    .attr('cx', 130)
  	.attr('cy', -200)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair6 = g
  .append('circle')
    .attr('cx', -120)
  	.attr('cy', -202)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair5 = g
  .append('circle')
    .attr('cx', -85)
  	.attr('cy', -220)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair4 = g
  .append('circle')
    .attr('cx', 98)
  	.attr('cy', -220)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair3 = g
  .append('circle')
    .attr('cx', 64)
  	.attr('cy', -240)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair2 = g
  .append('circle')
    .attr('cx', 25)
  	.attr('cy', -240)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair1 = g
  .append('circle')
    .attr('cx', -14)
  	.attr('cy', -240)
  	.attr('r', 20)
  	.attr('fill', 'black')

const hair = g
  .append('circle')
    .attr('cx', -50)
  	.attr('cy', -230)
  	.attr('r', 20)
  	.attr('fill', 'black')











